PROGRAM_NAME='ELMO, EV-400AF, RS-232, BASIC, 11-95, BA'
(*   DATE:05/20/99    TIME:15:33:44    *)
(***********************************************************)
(* The following code block is provided as a guide to      *)
(* programming the device(s) listed above. This is a       *)
(* sample only, and will most likely require modification  *)
(* to be integrated into a master program.                 *)
(*                                                         *)
(* Device-specific protocols should be obtained directly   *)
(* from the equipment manufacturer to ensure compliance    *)
(* with the most current versions. Within the limits       *)
(* imposed by any non-disclosure agreements, AMX will      *)
(* provide protocols upon request.                         *)
(*                                                         *)
(* If further programming assistance is required, please   *)
(* contact your AMX customer support team.                 *)
(*                                                         *)
(***********************************************************)
(* GENERAL FUNCTION LIST -                                 *)
(*   COLOR/B&W, FOCUS, INPUT, LAMPS, POSI/NEGA, ZOOM       *)
(***********************************************************)
(* NOTE:                                                   *)
(*   THIS UNIT REQUIRES HAND-SHAKING IN ORDER TO OPERATE,  *)
(*   AND THEREFORE MUST BE CONTROLLED BY AN AMX DEVICE     *)
(*   WHICH PROVIDES HAND-SHAKING CONNECTIONS (RTS & CTS).  *)
(*                                                         *)
(*   THIS UNIT CAN BE CONTROLLED EITHER BY A REMOTE DEVICE *)
(*   OR BY THE BUTTONS ON ITS FRONT-PANEL, BUT NOT BOTH AT *)
(*   THE SAME TIME. ALL OF THE FUNCTIONS IN THIS PROGRAM   *)
(*   ARE DESIGNED TO TEMPORARILY DISABLE THE UNIT'S FRONT- *)
(*   PANEL BUTTONS JUST LONG ENOUGH TO SEND THE            *)
(*   APPROPRIATE COMMANDS, AND THEN RETURN CONTROL TO THE  *)
(*   UNIT, WHICH ALLOWS FOR THE UNIT'S BUTTONS TO REMAIN   *)
(*   ACTIVE FOR MOST OF THE TIME.                          *)
(***********************************************************)
(*          DEVICE NUMBER DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_DEVICE

DOC_CAM = 1                            (* AXC-232: ELMO EV-400AF *)
PNL     = 128                          (* AMX PANEL *)

(***********************************************************)
(*               CONSTANT DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_CONSTANT

(***********************************************************)
(*               VARIABLE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_VARIABLE

(***********************************************************)
(*               LATCHING DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_LATCHING

(***********************************************************)
(*       MUTUALLY EXCLUSIVE DEFINITIONS GO BELOW           *)
(***********************************************************)
DEFINE_MUTUALLY_EXCLUSIVE

(***********************************************************)
(*           SUBROUTINE DEFINITIONS GO BELOW               *)
(***********************************************************)

(***********************************************************)
(*                STARTUP CODE GOES BELOW                  *)
(***********************************************************)
DEFINE_START

SEND_COMMAND DOC_CAM,'HSON'

(***********************************************************)
(*            THE ACTUAL PROGRAM GOES BELOW                *)
(***********************************************************)
DEFINE_PROGRAM

(*** LIGHTING ***)

PUSH[PNL,11]                           (* NONE *)
{
  SEND_STRING DOC_CAM,"5"                   (* ENABLE REMOTE *)
  WAIT 1 SEND_STRING DOC_CAM,"2,'PL0  ',3"  (* LAMPS OFF COMMAND *)
  WAIT 2 SEND_STRING DOC_CAM,"4"            (* DISABLE REMOTE *)
}

PUSH[PNL,12]                           (* BASE *)
{
  SEND_STRING DOC_CAM,"5"                   (* ENABLE REMOTE *)
  WAIT 1 SEND_STRING DOC_CAM,"2,'PL1  ',3"  (* BASE LAMP ON COMMAND *)
  WAIT 2 SEND_STRING DOC_CAM,"4"            (* DISABLE REMOTE *)
}

PUSH[PNL,13]                           (* UPPER *)
{
  SEND_STRING DOC_CAM,"5"                   (* ENABLE REMOTE *)
  WAIT 1 SEND_STRING DOC_CAM,"2,'PL2  ',3"  (* ARM LAMPS ON COMMAND *)
  WAIT 2 SEND_STRING DOC_CAM,"4"            (* DISABLE REMOTE *)
}


(*** INPUT SELECTION ***)

PUSH[PNL,14]                           (* INTERNAL *)
{
  SEND_STRING DOC_CAM,"5"                   (* ENABLE REMOTE *)
  WAIT 1 SEND_STRING DOC_CAM,"2,'AV0  ',3"  (* INTERNAL INPUT COMMAND *)
  WAIT 2 SEND_STRING DOC_CAM,"4"            (* DISABLE REMOTE *)
}

PUSH[PNL,15]                           (* AV 1 *)
{
  SEND_STRING DOC_CAM,"5"                   (* ENABLE REMOTE *)
  WAIT 1 SEND_STRING DOC_CAM,"2,'AV1  ',3"  (* AV 1 INPUT COMMAND *)
  WAIT 2 SEND_STRING DOC_CAM,"4"            (* DISABLE REMOTE *)
}

PUSH[PNL,16]                           (* AV 2 *)
{
  SEND_STRING DOC_CAM,"5"                   (* ENABLE REMOTE *)
  WAIT 1 SEND_STRING DOC_CAM,"2,'AV2  ',3"  (* AV 2 INPUT COMMAND *)
  WAIT 2 SEND_STRING DOC_CAM,"4"            (* DISABLE REMOTE *)
}


(*** POSITIVE / NEGATIVE ***)

PUSH[PNL,17]                           (* POSITIVE *)
{
  SEND_STRING DOC_CAM,"5"                   (* ENABLE REMOTE *)
  WAIT 1 SEND_STRING DOC_CAM,"2,'NP0  ',3"  (* POSITIVE COMMAND *)
  WAIT 2 SEND_STRING DOC_CAM,"4"            (* DISABLE REMOTE *)
}

PUSH[PNL,18]                           (* NEGATIVE *)
{
  SEND_STRING DOC_CAM,"5"                   (* ENABLE REMOTE *)
  WAIT 1 SEND_STRING DOC_CAM,"2,'NP1  ',3"  (* NEGATIVE COMMAND *)
  WAIT 2 SEND_STRING DOC_CAM,"4"            (* DISABLE REMOTE *)
}


(*** COLOR / BLACK & WHITE ***)

PUSH[PNL,19]                           (* COLOR *)
{
  SEND_STRING DOC_CAM,"5"                   (* ENABLE REMOTE *)
  WAIT 1 SEND_STRING DOC_CAM,"2,'CB0  ',3"  (* COLOR COMMAND *)
  WAIT 2 SEND_STRING DOC_CAM,"4"            (* DISABLE REMOTE *)
}

PUSH[PNL,20]                           (* BLACK & WHITE *)
{
  SEND_STRING DOC_CAM,"5"                   (* ENABLE REMOTE *)
  WAIT 1 SEND_STRING DOC_CAM,"2,'CB1  ',3"  (* BLACK & WHITE COMMAND *)
  WAIT 2 SEND_STRING DOC_CAM,"4"            (* DISABLE REMOTE *)
}


(*** ZOOM ***)

PUSH[PNL,21]                           (* TELE *)
{
  SEND_STRING DOC_CAM,"5"                   (* ENABLE REMOTE *)
  WAIT 1 SEND_STRING DOC_CAM,"2,'ZO+  ',3"  (* ZOOM TELE COMMAND *)
}
RELEASE[PNL,21]                        (* STOP *)
{
  SEND_STRING DOC_CAM,"2,'ZO0  ',3"         (* ZOOM STOP COMMAND *)
  WAIT 1 SEND_STRING DOC_CAM,"4"            (* DISABLE REMOTE *)
}

PUSH[PNL,22]                           (* WIDE *)
{
  SEND_STRING DOC_CAM,"5"                   (* ENABLE REMOTE *)
  WAIT 1 SEND_STRING DOC_CAM,"2,'ZO-  ',3"  (* ZOOM WIDE COMMAND *)
}
RELEASE[PNL,22]                        (* STOP *)
{
  SEND_STRING DOC_CAM,"2,'ZO0  ',3"         (* ZOOM STOP COMMAND *)
  WAIT 1 SEND_STRING DOC_CAM,"4"            (* DISABLE REMOTE *)
}


(*** FOCUS ***)

PUSH[PNL,23]                           (* NEAR *)
{
  SEND_STRING DOC_CAM,"5"                   (* ENABLE REMOTE *)
  WAIT 1 SEND_STRING DOC_CAM,"2,'FO+  ',3"  (* FOCUS NEAR COMMAND *)
}
RELEASE[PNL,23]                        (* STOP *)
{
  SEND_STRING DOC_CAM,"2,'FO0  ',3"         (* FOCUS STOP COMMAND *)
  WAIT 1 SEND_STRING DOC_CAM,"4"            (* DISABLE REMOTE *)
}

PUSH[PNL,24]                           (* FAR *)
{
  SEND_STRING DOC_CAM,"5"                   (* ENABLE REMOTE *)
  WAIT 1 SEND_STRING DOC_CAM,"2,'FO-  ',3"  (* FOCUS FAR COMMAND *)
}
RELEASE[PNL,24]                        (* STOP *)
{
  SEND_STRING DOC_CAM,"2,'FO0  ',3"         (* FOCUS STOP COMMAND *)
  WAIT 1 SEND_STRING DOC_CAM,"4"            (* DISABLE REMOTE *)
}

PUSH[PNL,25]                           (* AUTO FOCUS *)
{
  SEND_STRING DOC_CAM,"5"                   (* ENABLE REMOTE *)
  WAIT 1 SEND_STRING DOC_CAM,"2,'AF0  ',3"  (* AUTO FOCUS COMMAND *)
  WAIT 20 SEND_STRING DOC_CAM,"4"           (* DISABLE REMOTE *)
}


(*** MISC. ***)

PUSH[PNL,26]                           (* RESET *)
{
  SEND_STRING DOC_CAM,"5"                   (* ENABLE REMOTE *)
  WAIT 1 SEND_STRING DOC_CAM,"2,'DF0  ',3"  (* RESET TO DEFAULT COMMAND *)
  WAIT 2 SEND_STRING DOC_CAM,"4"            (* DISABLE REMOTE *)
}


(***********************************************************)
(*                     END OF PROGRAM                      *)
(*        DO NOT PUT ANY CODE BELOW THIS COMMENT           *)
(***********************************************************)

