PROGRAM_NAME='ELMO, EV-400AF, RS-232, ADVANCED, 11-95, BA'
(*   DATE:05/20/99    TIME:15:34:06    *)
(***********************************************************)
(* The following code block is provided as a guide to      *)
(* programming the device(s) listed above. This is a       *)
(* sample only, and will most likely require modification  *)
(* to be integrated into a master program.                 *)
(*                                                         *)
(* Device-specific protocols should be obtained directly   *)
(* from the equipment manufacturer to ensure compliance    *)
(* with the most current versions. Within the limits       *)
(* imposed by any non-disclosure agreements, AMX will      *)
(* provide protocols upon request.                         *)
(*                                                         *)
(* If further programming assistance is required, please   *)
(* contact your AMX customer support team.                 *)
(*                                                         *)
(***********************************************************)
(* GENERAL FUNCTION LIST -                                 *)
(*   COLOR/B&W, FOCUS, INPUT, LAMPS, POSI/NEGA, STATUS,    *)
(*   ZOOM                                                  *)
(***********************************************************)
(* NOTE:                                                   *)
(*   THIS UNIT REQUIRES HAND-SHAKING IN ORDER TO OPERATE,  *)
(*   AND THEREFORE MUST BE CONTROLLED BY AN AMX DEVICE     *)
(*   WHICH PROVIDES HAND-SHAKING CONNECTIONS (RTS & CTS).  *)
(*                                                         *)
(*   THIS UNIT CAN BE CONTROLLED EITHER BY A REMOTE DEVICE *)
(*   OR BY THE BUTTONS ON ITS FRONT-PANEL, BUT NOT BOTH AT *)
(*   THE SAME TIME. THE REMOTE DEVICE DETERMINES WHO HAS   *)
(*   CONTROL BY SENDING THE FOLLOWING CONTROL CODES: THE   *)
(*   "ENQ" CODE (HEX 05) ESTABLISHES COMMUNICATION BETWEEN *)
(*   THE UNIT AND THE REMOTE DEVICE, WHICH DISABLES THE    *)
(*   UNIT'S BUTTONS AND GIVES CONTROL TO THE REMOTE DEVICE,*)
(*   WHILE THE "EOT" CODE (HEX 04) ENDS COMMUNICATION      *)
(*   BETWEEN THE UNIT AND THE REMOTE DEVICE, WHICH GIVES   *)
(*   CONTROL BACK TO THE UNIT'S BUTTONS. EACH TIME THE     *)
(*   UNIT IS POWERED ON, CONTROL IS GIVEN TO THE UNIT.     *)
(***********************************************************)
(*          DEVICE NUMBER DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_DEVICE

DOC_CAM = 1                            (* AXC-232: ELMO EV-400AF *)
PNL     = 128                          (* AMX PANEL *)

(***********************************************************)
(*               CONSTANT DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_CONSTANT

(*** REQUEST TYPES ***)
STATUS_REQ  = 1
VERSION_REQ = 2

(***********************************************************)
(*               VARIABLE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_VARIABLE

DOC_CAM_BUFFER[10] (* STRING FOR DOCUMENT CAMERA BUFFER *)
REQUEST_TYPE       (* LAST TYPE OF REQUEST SENT TO DOC. CAMERA *)
STATUS[4]          (* ARRAY FOR STORING STATUS INFORMATION *)
VERSION[6]         (* STRING FOR STORING DOC. CAMERA VERSION *)

(***********************************************************)
(*               LATCHING DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_LATCHING

(***********************************************************)
(*       MUTUALLY EXCLUSIVE DEFINITIONS GO BELOW           *)
(***********************************************************)
DEFINE_MUTUALLY_EXCLUSIVE

(***********************************************************)
(*           SUBROUTINE DEFINITIONS GO BELOW               *)
(***********************************************************)

(***********************************************************)
(*                STARTUP CODE GOES BELOW                  *)
(***********************************************************)
DEFINE_START

SEND_COMMAND DOC_CAM,'HSON'
CREATE_BUFFER DOC_CAM,DOC_CAM_BUFFER

(***********************************************************)
(*            THE ACTUAL PROGRAM GOES BELOW                *)
(***********************************************************)
DEFINE_PROGRAM


(*** CHECK BUFFER ***)
IF (LENGTH_STRING(DOC_CAM_BUFFER))
{
  SELECT
  {
    ACTIVE(LEFT_STRING(DOC_CAM_BUFFER,1)="$06"):
    {
      (* LAST COMMAND WAS RECEIVED SUCCESSFULLY. *)
    }
    ACTIVE(LEFT_STRING(DOC_CAM_BUFFER,1)="$15"):
    {
      (* LAST COMMAND WAS NOT RECEIVED SUCCESSFULLY. *)
    }
    ACTIVE(LEFT_STRING(DOC_CAM_BUFFER,1)="$02"):
    {
      IF (REQUEST_TYPE = STATUS_REQ)
      {
        (* RESPONSE TO STATUS REQUEST. *)
        STATUS = MID_STRING(DOC_CAM_BUFFER,2,4)
        (* KEY (ALL VALUES ARE ASCII CHARACTERS):                *)
        (* STATUS[1]: 0=NO LAMPS, 1=BASE LAMP, 2=ARM LAMPS       *)
        (* STATUS[2]: 0=INTERNAL INPUT, 1=AV1 INPUT, 2=AV2 INPUT *)
        (* STATUS[3]: 0=POSITIVE IMAGE, 1=NEGATIVE IMAGE         *)
        (* STATUS[4]: 0=COLOR IMAGE, 1=BLACK & WHITE IMAGE       *)
      }
      ELSE IF (REQUEST_TYPE = VERSION_REQ)
      {
        (* RESPONSE TO VERSION REQUEST. *)
        VERSION = MID_STRING(DOC_CAM_BUFFER,2,6)
      }
    }
  }
  DOC_CAM_BUFFER = ""
}


(*** CONTROL CODES ***)
PUSH[PNL,1]                            (* ENQ (ESTABLISH COMMUNICATION) *)
  SEND_STRING DOC_CAM,"$05"

PUSH[PNL,2]                            (* EOT (END COMMUNICATION) *)
  SEND_STRING DOC_CAM,"$04"


(*** LIGHTING ***)

PUSH[PNL,11]                           (* NO LAMPS ON *)
  SEND_STRING DOC_CAM,"2,'PL0  ',3"

PUSH[PNL,12]                           (* BASE LAMP ON *)
  SEND_STRING DOC_CAM,"2,'PL1  ',3"

PUSH[PNL,13]                           (* UPPER LAMPS ON *)
  SEND_STRING DOC_CAM,"2,'PL2  ',3"


(*** INPUT SELECTION ***)

PUSH[PNL,14]                           (* INTERNAL INPUT *)
  SEND_STRING DOC_CAM,"2,'AV0  ',3"

PUSH[PNL,15]                           (* AV 1 INPUT *)
  SEND_STRING DOC_CAM,"2,'AV1  ',3"

PUSH[PNL,16]                           (* AV 2 INPUT *)
  SEND_STRING DOC_CAM,"2,'AV2  ',3"


(*** POSITIVE / NEGATIVE ***)

PUSH[PNL,17]                           (* POSITIVE *)
  SEND_STRING DOC_CAM,"2,'NP0  ',3"

PUSH[PNL,18]                           (* NEGATIVE *)
  SEND_STRING DOC_CAM,"2,'NP1  ',3"


(*** COLOR / BLACK & WHITE ***)

PUSH[PNL,19]                           (* COLOR *)
  SEND_STRING DOC_CAM,"2,'CB0  ',3"

PUSH[PNL,20]                           (* BLACK & WHITE *)
  SEND_STRING DOC_CAM,"2,'CB1  ',3"


(*** ZOOM ***)

PUSH[PNL,21]                           (* TELE *)
  SEND_STRING DOC_CAM,"2,'ZO+  ',3"
RELEASE[PNL,21]                        (* STOP *)
  SEND_STRING DOC_CAM,"2,'ZO0  ',3"

PUSH[PNL,22]                           (* WIDE *)
  SEND_STRING DOC_CAM,"2,'ZO-  ',3"
RELEASE[PNL,22]                        (* STOP *)
  SEND_STRING DOC_CAM,"2,'ZO0  ',3"


(*** FOCUS ***)

PUSH[PNL,23]                           (* NEAR *)
  SEND_STRING DOC_CAM,"2,'FO+  ',3"
RELEASE[PNL,23]                        (* STOP *)
  SEND_STRING DOC_CAM,"2,'FO0  ',3"

PUSH[PNL,24]                           (* FAR *)
  SEND_STRING DOC_CAM,"2,'FO-  ',3"
RELEASE[PNL,24]                        (* STOP *)
  SEND_STRING DOC_CAM,"2,'FO0  ',3"

PUSH[PNL,25]                           (* AUTO FOCUS *)
  SEND_STRING DOC_CAM,"2,'AF0  ',3"


(*** MISC. ***)

PUSH[PNL,26]                           (* RESET *)
  SEND_STRING DOC_CAM,"2,'DF0  ',3"

PUSH[PNL,27]                           (* STATUS REQUEST *)
{
  REQUEST_TYPE = STATUS_REQ
  SEND_STRING DOC_CAM,"2,'QS0  ',3"
}

PUSH[PNL,28]                           (* VERSION REQUEST *)
{
  REQUEST_TYPE = VERSION_REQ
  SEND_STRING DOC_CAM,"2,'QR0  ',3"
}


(***********************************************************)
(*                     END OF PROGRAM                      *)
(*        DO NOT PUT ANY CODE BELOW THIS COMMENT           *)
(***********************************************************)

